/****************************************************************************
 *  FileName::fmapi.h
 *
 *  Purpose::   1. Define macros used by application
 *              2. Define function prototypes used by application
 *            
 *                                          Zhou Chuansheng
 *                                           June. 23.1994
 *
 *  Modify::    Add function document.
 *              Chen Yao. Nov. 11. 1994
 *
 ***************************************************************************/

// Define the Min, Max and Base frequency
#define MIN_FREQUENCY       87500   //(K Hz)
#define MAX_FREQUENCY       108000  //(K Hz)
#define BASE_FREQUENCY      10700   //(K Hz)
#define REF_FREQUENCY       10      //(K Hz)

// Define FM radio hardware type
#define RADIO_UNKNOWN                       0x0000
#define RADIO_BUILT_IN                      0x0001
#define RADIO_EXTENSION                     0x0002
#define RADIO_STAND_ALONE                   0x0003
#define RADIO_WASHTON_BUILTIN               0x0004
#define RADIO_CARD2_350                     0x0005
#define RADIO_CARD2_358                     0x0006
#define RADIO_CARD3_350                     0x0007
#define RADIO_CARD3_358                     0x0008
#define RADIO_CARD3B_350                    0x0009
#define RADIO_CARD3B_358                    0x000A
#define RADIO_CARD3C_350					0x000B
#define RADIO_CARD3C_358					0x000C

/// Define FM radio volume macros
#define MAX_RADIO_VOLUME                    0xFFFF
#define MAX_BASS_VOLUME                     0xFFFF
#define MAX_TREBLE_VOLUME                   0xFFFF

// Define the error message
#define ERR_HARDWARE_NOT_FOUND              0x1001
#define ERR_HARDWARE_NOT_SUPPORT            0x1002

/****************************************************************************
 *
 *  Export Function :
 *
 *  1.  FM_InitializeRadio
 *
 *      Syntax          WORD FM_InitializeRadio(WORD HardwareType);
 *
 *      Paraneter       Description
 *      HardwareType    FM radio hardware type
 *
 *                      =  RADIO_UNKNOWN
 *                      =  RADIO_BUILT_IN         NOVA-16 radio buildin
 *                      =  RADIO_EXTENSION        NOVA-16 radio extention
 *                      =  RADIO_WASHTON_BUILTIN  WASHINGTON-16 radio buildin
 *                      =  RADIO_STAND_ALONE      FM RADIO I
 *                      =  RADIO_CARD2_350        FM RADIO ][ address on 350H
 *                      =  RADIO_CARD2_358        FM RADIO ][ address on 358H
 *
 *
 *      This function reads SYSTEM.INI and return the FM radio hardware type
 *      if RADIO_UNKNOWN is specificed. Otherwise it initializes the FM radio 
 *      hardware. Initialize must be done before call other function in this
 *      DLL.
 *
 *      Return Value
 *
 *      The FM_InitializeRadio function return correct FM radio hardware type 
 *      if success.A return value of ERR_HARDWARE_NOT_FOUND or
 *      ERR_HARDWARE_NOT_SUPPORT indicates an error.
 *         
 *
 *  2.  FM_SetRadioFrequency
 *
 *      Syntax          void FM_SetRadioFrequency(DWORD dwFrequency);
 *
 *      Paraneter       Description
 *      dwFrequency     FM radio frequency
 *
 *      This function sets the FM radio to a given frequency.
 *
 *
 *  3.  FM_IsRadioStation
 *
 *      Syntax          BOOL FM_IsRadioStation();
 *
 *      Determine if the current setting is a station or not
 *
 *      Return Value    Meaning
 *      TRUE            Is a station
 *      FALSE           Is not a station
 *
 *
 *  4.  FM_SetRadioMute
 *
 *      Syntax          BOOL FM_SetRadioMute(BOOL bTrueFalse);
 *
 *      Paraneter       Description
 *      bTrueFalse      = TRUE    mute the FM radio
 *                      = FALSE   unmute the FM radio
 *
 *      Mute or Unmute the FM radio.
 *
 *      Return Value    Meaning
 *      TRUE            Success
 *      FALSE           Failure
 *
 *
 *  5.  FM_SetRadioStereo(BOOL bTrueFalse)
 *
 *      Syntax          BOOL FM_SetRadioStereo(BOOL bTrueFalse);
 *
 *      Paraneter       Description
 *      bTrueFalse      = TRUE    set the FM radio to stereo
 *                      = FALSE   set the FM radio to mono
 *
 *      Set the FM radio to stereo on mono state.
 *
 *      Return Value    Meaning
 *      TRUE            Success
 *      FALSE           Failure
 *
 *
 *  6.  FM_SetRadioVolume
 *
 *      Syntax          BOOL FM_SetRadioVolume(WORD wVolume);
 *
 *      Paraneter       Description
 *      wVolume         FM radio volume (0x0000 -- 0xFFFF)
 *
 *      Set the FM radio volume.
 *
 *      Return Value    Meaning
 *      TRUE            Success
 *      FALSE           Failure
 *
 *
 *  7.  FM_SetRadioBassVolume
 *
 *      Syntax          BOOL FM_SetRadioBass(WORD wVolume);
 *
 *      Paraneter       Description
 *      wVolume         FM radio base volume (0x0000 -- 0xFFFF)
 *
 *      Set the FM radio bass volume.
 *      This function is only for FM RADIO I hardware.
 *      (HardwareType == RADIO_STAND_ALONE)
 *
 *      Return Value    Meaning
 *      TRUE            Success
 *      FALSE           Failure
 *
 *
 *  8.  FM_SetRadioTreble(word volume)
 *
 *      Syntax          BOOL FM_SetRadioTreble(WORD wVolume);
 *
 *      Paraneter       Description
 *      wVolume         FM radio treble volume (0x0000 -- 0xFFFF)
 *
 *      Set the FM radio treble volume.
 *      This function is only for FM RADIO I hardware.
 *      (HardwareType == RADIO_STAND_ALONE)
 *
 *      Return Value    Meaning
 *      TRUE            Success
 *      FALSE           Failure
 *
 *
 *  9.  FM_GetRadioFrequency
 *
 *      Syntax          DWORD FM_GetRadioFrequency();
 *
 *      Get the FM radio current frequency.
 *
 *      Return Value
 *      Return the FM radio current frequency.
 *      If you never set FM radio frequency, it will return 0.
 *
 *
 *  10. FM_GetRadioMuteMode
 *
 *      Syntax          BOOL FM_GetRadioMuteMode();
 *
 *      Get the FM radio current mute state.
 *
 *      Return Value    Meaning
 *      TRUE            FM radio is mute.
 *      FALSE           FM radio is unmute.
 *
 *
 *  11. FM_GetRadioStereoMode()
 *
 *      Syntax          BOOL FM_GetRadioStereoMode();
 *
 *      Get the FM radio current stereo/mono state.
 *
 *      Return Value    Meaning
 *      TRUE            FM radio is stereo.
 *      FALSE           FM radio is mono.
 *
 *
 *  12. FM_GetRadioVolume
 *
 *      Syntax          WORD FM_GetRadioVolume();
 *
 *      Get FM radio current volume.
 *
 *      Return Value
 *      Return the FM radio current volume.
 *
 *
 *  13. FM_GetRadioBassVolume()
 *
 *      Syntax          WORD FM_GetRadioBassVolume();
 *
 *      Get FM radio current base volume.
 *      This function is only for FM RADIO I hardware.
 *      (HardwareType == RADIO_STAND_ALONE)
 *
 *      Return Value
 *      Return the FM radio current base volume.
 *
 *
 *  14. FM_GetRadioTreble()
 *
 *      Syntax          WORD FM_GetRadioTreble();
 *
 *      Get FM radio current treble volume.
 *      This function is only for FM RADIO I hardware.
 *      (HardwareType == RADIO_STAND_ALONE)
 *
 *      Return Value
 *      Return the FM radio current treble volume.
 *
 *
 *  15. FM_CloseRadio()
 *
 *      Syntax          BOOL FAR PASCAL _export FM_CloseRadio();
 *
 *      This function saves all the information to SYSTEM.INI file.
 *
 *      Return Value    Meaning
 *      TRUE            Success
 *      FALSE           Failure
 *
 *
 *************************************************************************************/
#ifdef __cplusplus
extern "C" {
#endif  /* __cplusplus */

WORD    FAR PASCAL _export FM_InitializeRadio(WORD HardwareType);
void    FAR PASCAL _export FM_SetRadioFrequency(DWORD dwFreqequency);
BOOL    FAR PASCAL _export FM_IsRadioStation();
BOOL    FAR PASCAL _export FM_SetRadioMute(BOOL TrueFalse);
BOOL    FAR PASCAL _export FM_SetRadioStereo(BOOL TrueFalse);
BOOL    FAR PASCAL _export FM_SetRadioVolume(WORD volume);
BOOL    FAR PASCAL _export FM_SetRadioBass(WORD volume);
BOOL    FAR PASCAL _export FM_SetRadioTreble(WORD volume);

DWORD   FAR PASCAL _export FM_GetRadioFrequency();
BOOL    FAR PASCAL _export FM_GetRadioMuteMode();
BOOL    FAR PASCAL _export FM_GetRadioStereoMode();
WORD    FAR PASCAL _export FM_GetRadioVolume();
WORD    FAR PASCAL _export FM_GetRadioBass();
WORD    FAR PASCAL _export FM_GetRadioTreble();
BOOL    FAR PASCAL _export FM_CloseRadio();

#ifdef __cplusplus
}
#endif
